@@ -469,28 +469,39 @@ class HardwareIOTypeForm(forms.Form):
         fields = ['type', 'parent_hardware', 'child_hardware', 'child_channel', 'hub']
 
 
-from django.forms.models import inlineformset_factory, BaseModelFormSet, BaseInlineFormSet,BaseModelForm
+from django.forms.models import inlineformset_factory, BaseModelFormSet, BaseInlineFormSet, BaseModelForm
 from data.models.models import HardwareStats, DataTransformer, DataTransformerConstants, HardwareDataTransformer, \
     HardwareStatsDataTransformer
 
 # DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer, fk_name='data_transformer_parent',
 #                                                      extra=1,exclude =['updated_at','created_at'],formset=DataTransformerForm)
-DataConstantsTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformerConstants, extra=1,exclude =['updated_at','created_at'])
-HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareDataTransformer, extra=1,exclude =['updated_at','created_at'])
-HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1,exclude =['updated_at','created_at'])
+DataConstantsTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformerConstants, extra=1,
+                                                              exclude=['updated_at', 'created_at'])
+HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareDataTransformer, extra=1,
+                                                         exclude=['updated_at', 'created_at'])
+HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1,
+                                                              exclude=['updated_at', 'created_at'])
 
 
 class DataTransformerForm(BaseInlineFormSet):
+    id = forms.CharField(required=False,
+                         widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    accessory = forms.CharField(required=False,
+                                widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+
+    data_transformer_parent = forms.CharField(required=False,
+                                              widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    type = forms.CharField(required=True,
+                           widget=forms.TextInput(attrs={'class': 'form-control'}))
 
     def __init__(self, *args, **kwargs):
         self.DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
-                                                             fk_name='data_transformer_parent',
-                                                             extra=1, exclude=['updated_at', 'created_at'],
-                                                             form=self.__class__)
+                                                                  fk_name='data_transformer_parent',
+                                                                  extra=1, exclude=['updated_at', 'created_at'],
+                                                                  form=self.__class__)
 
         super(DataTransformerForm, self).__init__(*args, **kwargs)
 
-
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
 
