@@ -311,6 +311,7 @@ class DataTransformer(models.Model):
         null=False
     )
     data_transformer_parent = models.ForeignKey('self', on_delete=models.CASCADE, blank=True, null=True, default=None)
+    type = models.CharField(max_length=255,  blank=True, null=True, default=None)
 
     def save(self, *args, **kwargs):
         if not self.created_at:
@@ -350,7 +351,7 @@ class HardwareDataTransformer(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
     hardware = models.ForeignKey(Hardware, on_delete=models.CASCADE, blank=True, null=True, default=None)
     data_transformer = models.ForeignKey(DataTransformer,on_delete=models.CASCADE, blank=True, null=True, default=None)
-    index = models.IntegerField()
+    index = models.IntegerField(blank=True, null=True, default=None)
     updated_at = models.DateTimeField(auto_now=True)
     created_at = models.DateTimeField(auto_now_add=True)
 
