@@ -389,7 +389,10 @@ class AccessoryViewSet(viewsets.ModelViewSet):
             data_transformer = accessory.datatransformer
             formset = DataTransformerForm(instance=data_transformer)
         else:
-            formset = DataTransformerForm(initial={'accessory': accessory})
+            data_transformer = DataTransformer()
+            data_transformer.accessory = accessory
+            data_transformer.save()
+            formset = DataTransformerForm(instance=data_transformer)
 
 
 
